@@ -36,6 +36,10 @@ class TestGPUArray:
         result = (a_gpu**a_gpu).get()
         assert (np.abs(pow(a, a) - result) < 1e-3).all()
 
+        a_gpu **= a_gpu
+        a_gpu = a_gpu.get()
+        assert (np.abs(pow(a, a) - a_gpu) < 1e-3).all()
+
     @mark_cuda_test
     def test_pow_number(self):
         a = np.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10]).astype(np.float32)
@@ -44,6 +48,10 @@ class TestGPUArray:
         result = pow(a_gpu, 2).get()
         assert (np.abs(a**2 - result) < 1e-3).all()
 
+        a_gpu **= 2
+        a_gpu = a_gpu.get()
+        assert (np.abs(a**2 - a_gpu) < 1e-3).all()
+
     @mark_cuda_test
     def test_numpy_integer_shape(self):
         gpuarray.empty(np.int32(17), np.float32)
@@ -944,6 +952,9 @@ class TestGPUArray:
 
     @mark_cuda_test
     def test_dot_allocator(self):
+        from pytest import skip
+        skip("https://github.com/inducer/pycuda/issues/163")
+
         import pycuda.tools
         pool = pycuda.tools.DeviceMemoryPool()
 
@@ -1142,5 +1153,5 @@ if __name__ == "__main__":
     if len(sys.argv) > 1:
         exec (sys.argv[1])
     else:
-        from py.test.cmdline import main
+        from pytest import main
         main([__file__])
